API documentation
=================

This is the definite source of information for developers, besides having a look at the actual source code. Each class and public method should be fully documented.

Besides information necessary for the developer, the modules increasingly contain information on the context the classes implemented may be used. This is particularly true for the processing and analysis steps.


Subpackages
-----------

An alphabetic list of the subpackages available within the cwepr package. The actual documentation is split in pages for each submodule of each subpackage, respectively.

.. toctree::
   :maxdepth: 2

   cwepr.io

Submodules
----------

An alphabetic list of the submodules available within the cwepr package. The actual documentation is split in pages for each submodule, respectively.

.. toctree::
   :maxdepth: 1

   cwepr.analysis
   cwepr.dataset
   cwepr.exceptions
   cwepr.metadata
   cwepr.plotting
   cwepr.processing
   cwepr.report
   cwepr.utils
